@@ -18,6 +18,31 @@ describe 'gnocchi::api' do
     }
   end
 
+  shared_examples_for 'gnocchi-api wsgi' do
+    context 'with gnocchi-api in wsgi' do
+      before do
+        params.merge!({ :service_name => 'httpd' })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         include ::gnocchi::db
+         class { 'gnocchi': }
+         class { '::gnocchi::keystone::authtoken':
+           password => 'gnocchi-passw0rd',
+         }"
+      end
+
+      it 'installs gnocchi-api package' do
+        is_expected.to contain_package('gnocchi-api').with(
+          :ensure => 'latest',
+          :name   => platform_params[:api_package_name],
+          :tag    => ['openstack', 'gnocchi-package'],
+        )
+      end
+    end
+  end
+
   shared_examples_for 'gnocchi-api' do
 
     it { is_expected.to contain_class('gnocchi::deps') }
@@ -35,8 +60,10 @@ describe 'gnocchi::api' do
     it 'configures gnocchi-api' do
       is_expected.to contain_gnocchi_config('api/max_limit').with_value( params[:max_limit] )
       is_expected.to contain_gnocchi_config('api/auth_mode').with_value('keystone')
-      is_expected.to contain_gnocchi_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_gnocchi_config('api/middlewares').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('gnocchi_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -133,7 +160,9 @@ describe 'gnocchi::api' do
         params.merge!({:enable_proxy_headers_parsing => true })
       end
 
-      it { is_expected.to contain_gnocchi_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+      it { is_expected.to contain_oslo__middleware('gnocchi_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
     end
 
   end
@@ -149,9 +178,16 @@ describe 'gnocchi::api' do
       end
 
       let(:platform_params) do
-        { :api_package_name => 'gnocchi-api',
+        if facts[:operatingsystem] == 'Ubuntu' then
+          package_name = 'python-gnocchi'
+        else
+          package_name = 'gnocchi-api'
+        end
+        { :api_package_name => package_name,
           :api_service_name => 'gnocchi-api' }
       end
+
+      it_behaves_like 'gnocchi-api wsgi'
       it_behaves_like 'gnocchi-api'
     end
   end
