@@ -20,7 +20,7 @@ describe 'gnocchi::keystone::authtoken' do
         is_expected.to contain_gnocchi_config('keystone_authtoken/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/auth_section').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/auth_type').with_value('password')
-        is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value('http://localhost:5000')
+        is_expected.to contain_gnocchi_config('keystone_authtoken/www_authenticate_uri').with_value('http://localhost:5000')
         is_expected.to contain_gnocchi_config('keystone_authtoken/auth_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
@@ -43,7 +43,6 @@ describe 'gnocchi::keystone::authtoken' do
         is_expected.to contain_gnocchi_config('keystone_authtoken/memcache_use_advanced_pool').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_gnocchi_config('keystone_authtoken/revocation_cache_time').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_gnocchi_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
       end
     end
@@ -51,7 +50,7 @@ describe 'gnocchi::keystone::authtoken' do
     context 'when overriding parameters' do
       before do
         params.merge!({
-          :auth_uri                             => 'https://10.0.0.1:9999/',
+          :www_authenticate_uri                 => 'https://10.0.0.1:9999/',
           :username                             => 'myuser',
           :password                             => 'mypasswd',
           :auth_url                             => 'http://:127.0.0.1:35357',
@@ -84,13 +83,12 @@ describe 'gnocchi::keystone::authtoken' do
           :memcached_servers                    => ['memcached01:11211','memcached02:11211'],
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
-          :revocation_cache_time                => '11',
           :token_cache_time                     => '301',
         })
       end
 
       it 'configure keystone_authtoken' do
-        is_expected.to contain_gnocchi_config('keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
+        is_expected.to contain_gnocchi_config('keystone_authtoken/www_authenticate_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_gnocchi_config('keystone_authtoken/username').with_value(params[:username])
         is_expected.to contain_gnocchi_config('keystone_authtoken/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_gnocchi_config('keystone_authtoken/auth_url').with_value(params[:auth_url])
@@ -122,7 +120,6 @@ describe 'gnocchi::keystone::authtoken' do
         is_expected.to contain_gnocchi_config('keystone_authtoken/memcache_use_advanced_pool').with_value(params[:memcache_use_advanced_pool])
         is_expected.to contain_gnocchi_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_gnocchi_config('keystone_authtoken/region_name').with_value(params[:region_name])
-        is_expected.to contain_gnocchi_config('keystone_authtoken/revocation_cache_time').with_value(params[:revocation_cache_time])
         is_expected.to contain_gnocchi_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
       end
 
